/*
 * Copyright 2003, Sandro Giessl <ceebx@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License version 2 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef KNIFTY_H
#define KNIFTY_H

#include <kwin/client.h>
#include <qfont.h>



namespace KWinInternal {

enum ButtonType {
    ButtonHelp=0,
    ButtonMax,
    ButtonMin,
    ButtonClose,
    ButtonMenu,
    ButtonSticky,
    ButtonTypeCount
};

enum ColorType {
    WindowContour=0,
    TitleGradientFrom,
    TitleGradientTo,
    TitleGradientToTop,
    TitleHighlightTop,
    SideHighlightLeft,
    SideHighlightRight,
    SideHighlightBottom,
    Border,
    TitleFont
};

class PlastikHandler: public QObject
{
    Q_OBJECT
public:
    PlastikHandler();
    ~PlastikHandler();
    void reset();

    static bool initialized() { return m_initialized; }

    static int  titleHeight() { return m_titleHeight; }
    static int  titleHeightTool() { return m_titleHeightTool; }
    static QFont titleFont() { return m_titleFont; }
    static QFont titleFontTool() { return m_titleFontTool; }
    static bool titleShadow() { return m_titleShadow; }
    static bool shrinkBorders() { return m_shrinkBorders; }
    static int  borderSize() { return m_borderSize; }
    static bool useHighContrastHoveredButtons() { return m_useHighContrastHoveredButtons; }
    static bool animateButtons() { return m_animateButtons; }
    static Qt::AlignmentFlags titleAlign() { return m_titleAlign; }
    static QColor getColor(ColorType type, const bool active = true);
private:
    void readConfig();

    static bool m_titleShadow;
    static bool m_shrinkBorders;
    static bool m_useHighContrastHoveredButtons;
    static bool m_animateButtons;
    static int  m_borderSize;
    static int  m_titleHeight;
    static int  m_titleHeightTool;
    static QFont m_titleFont;
    static QFont m_titleFontTool;
    static Qt::AlignmentFlags m_titleAlign;

    static bool m_initialized;
};

} // namespace KWinInternal

#endif // KNIFT_H
